@@ -34,6 +34,53 @@ sub apply_node_navopts {}
 
 has '+fetch_nodes_deep', default => 0;
 
+
+has '+node_types', default => sub {[
+  {
+    type     => 'folder',
+    title    => 'Folder',
+    iconCls  => 'ra-icon-folder',
+    addable  => 1,
+    editable => 1
+  },
+  {
+    type     => 'search',
+    title    => 'Saved Search',
+    addable  => 0,
+    editable => 1
+  },
+  {
+    type     => 'link',
+    title    => 'Custom Link',
+    iconCls  => 'ra-icon-link-go',
+    addable  => 1,
+    editable => 1,
+    applyDialogOpts => {
+      height => 200,
+    },
+    fields => [{
+      name  => 'iconcls',
+      xtype => 'ra-all-icon-assets-combo',
+      value => 'ra-icon-link-go',
+      fieldLabel => 'Icon',
+    },{
+      name  => 'url', 
+      xtype => 'textfield',
+      fieldLabel => 'Link URL',
+      plugins => [{
+        ptype => 'fieldhelp',
+        text  => "Local internal URL path, starting with '/'"
+      }],
+      allowBlank => \0,
+      validator => jsfunc join(' ','function(v) {',
+        'return (v && v.search("/") == 0) ? true : false;',
+      '}')
+    }]
+  },
+
+]};
+
+
 sub auth_active {
   my $self = shift;
   return $self->c->can('user') ? 1 : 0;
@@ -236,9 +283,7 @@ sub user_searches_nodes {
 
 
 sub add_node {
-	my $self = shift;
-	my $name = shift;
-	my $node = shift;
+  my ($self,$name,$node,$params) = @_;
 	
 	my $id = $self->get_node_id($node);
 	
@@ -247,12 +292,28 @@ sub add_node {
 	$name =~ s/\s+$//;
 	
 	my $order = $self->get_order_string($id,'append');
-	
-	my $Node = $self->Rs->create({
-		pid => $id,
-		text => $name,
-		ordering => $order
-	});
+  
+  my $Node;
+  if(($params->{nodeTypeName}||'folder') eq 'link') {
+    my $url = $params->{url} or die usererr "Link URL is required";
+    my $uid = $self->c->user->get_column('id');
+    
+    $Node = $self->SearchesRs->create({
+      node_id => $id,
+      user_id => $uid,
+      title => $name,
+      ordering => $order,
+      url => $url,
+      iconcls => $params->{iconcls} || 'ra-icon-link-go',
+    });
+  }
+  else {
+    $Node = $self->Rs->create({
+      pid => $id,
+      text => $name,
+      ordering => $order
+    });
+  }
 	
 	return {
 		msg		=> 'Created',
@@ -567,9 +628,7 @@ sub get_order_string {
 
 
 sub rename_node {
-	my $self = shift;
-	my $node = shift;
-	my $name = shift;
+  my ($self,$node,$name,$params) = @_;
 	
 	# strip whitespace
 	$name =~ s/^\s+//;
@@ -577,7 +636,7 @@ sub rename_node {
 	
 	#my $id = $self->get_node_id($node);
 	my $Node = $self->get_node_Row($node) or die "Failed to get Node";
-	return $self->rename_search($Node,$name) if ($Node->can('node_id'));
+	return $self->rename_search($Node,$name,$params) if ($Node->can('node_id'));
 	
 	#my $Node = $self->Rs->search_rs({ 'me.id' => $id })->first;
 	$Node->update({ 'text' => $name });
@@ -590,16 +649,31 @@ sub rename_node {
 }
 
 sub rename_search {
-	my $self = shift;
-	my $State = shift;
-	my $name = shift;
-	
-	return {
-		msg		=> 'Renamed Search',
-		success	=> \1,
-		new_text => $State->title
-	} if ($State->update({ title => $name }));
-	
+  my ($self,$State,$name,$params) = @_;
+  
+  my $nodeTypeName = $params->{nodeTypeName} || '';
+  
+  my $update = { title => $name };
+  if($nodeTypeName eq 'link') {
+    $update->{url}     = $params->{url}     if ($params->{url});
+    $update->{iconcls} = $params->{iconcls} if ($params->{iconcls});
+  }
+  
+  if ($State->update($update)) {
+    my $res = {
+      msg		=> 'Renamed Search',
+      success	=> \1,
+      new_text => $State->title,
+      new_iconcls => $State->iconcls
+    };
+    
+    if($nodeTypeName eq 'link') {
+      $res->{new_attributes} = $self->get_Node_config($State);
+    }
+    
+    return $res;
+  }
+  
 	die "Rename error";
 }
 
