@@ -305,6 +305,14 @@ Ext.ux.RapidApp.AppCombo2.IconCombo = Ext.extend(Ext.ux.RapidApp.AppCombo2.CssCo
 });
 Ext.reg('ra-icon-combo',Ext.ux.RapidApp.AppCombo2.IconCombo);
 
+
+Ext.ux.RapidApp.AppCombo2.AllIconAssetsCombo = Ext.extend(Ext.ux.RapidApp.AppCombo2.IconCombo,{
+  // This global is generated by the backend in RapidApp::Role::AssetControllers
+  value_list: Ext.ux.RapidApp.AllIconAssetClsNames
+});
+Ext.reg('ra-all-icon-assets-combo',Ext.ux.RapidApp.AppCombo2.AllIconAssetsCombo);
+
+
 // TODO: remove Ext.ux.MultiFilter.StaticCombo and reconfigure MultiFilter
 // to use this here as a general purpose component
 Ext.ux.RapidApp.StaticCombo = Ext.extend(Ext.ux.RapidApp.AppCombo2.CssCombo,{
